<?php
/**
 * Plugin Name: GPP Base Hook Widgets
 * Plugin URI: http://graphpaperpress.com/plugins/gpp-base-hook-widgets
 * Description: Adds widget areas to the action hooks in the Base theme, allowing you to customize your site without digging into the theme files.
 * Version: 1.2
 * Author: Thad Allender
 * Author URI: http://graphpaperpress.com.com
 *
 * This plugin was created so that users with little or no PHP 
 * knowledge could take advantage of Base's built-in hook system.  It allows
 * them to add widgets to specific action hooks.  The user must have WordPress
 * version 3.0.4 or higher installed to use this plugin.
 *
 * @copyright 2010 - 2011
 * @version 1.2
 * @author Thad Allender
 * @link http://graphpaperpress.com/plugins/gpp-base-hook-widgets
 * @license http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @package GPP Base Hook Widgets
 */

/**
 * Add functions to action hooks available in WP and Base.
 * @since 1.0
 */
add_action( 'init', 'gpp_base_gpp_base_hook_widgets_register' );
add_action( 'gpp_base_above_header_hook', 'gpp_base_hook_widgets_before_header', 11 );
add_action( 'gpp_base_header_hook', 'gpp_base_hook_widgets_header', 11 );
add_action( 'gpp_base_below_header_hook', 'gpp_base_hook_widgets_after_header', 11 );
add_action( 'gpp_base_above_content_hook', 'gpp_base_hook_widgets_before_content', 11 );
add_action( 'gpp_base_below_content_hook', 'gpp_base_hook_widgets_after_content', 11 );
add_action( 'gpp_base_above_title_hook', 'gpp_base_hook_widgets_before_title', 11 );
add_action( 'gpp_base_below_title_hook', 'gpp_base_hook_widgets_after_title', 11 );
add_action( 'gpp_base_above_sidebar_hook', 'gpp_base_hook_widgets_before_sidebar', 11 );
add_action( 'gpp_base_below_sidebar_hook', 'gpp_base_hook_widgets_after_sidebar', 11 );
add_action( 'gpp_base_above_footer_hook', 'gpp_base_hook_widgets_before_footer', 11 );
add_action( 'gpp_base_below_footer_hook', 'gpp_base_hook_widgets_after_footer', 11 );

/**
 * Create the additional widget areas for the plugin.
 * @uses register_sidebar() Creates new widget areas.
 *
 * @since 1.0
 */
function gpp_base_gpp_base_hook_widgets_register() {
	register_sidebar( array( 'name' => __('Base: Before Header', 'hook_widgets'), 'id' => 'hook-before-header', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: Header', 'hook_widgets'), 'id' => 'hook-header', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: After Header', 'hook_widgets'), 'id' => 'hook-after-header', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: Before Content', 'hook_widgets'), 'id' => 'hook-before-content', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: After Content', 'hook_widgets'), 'id' => 'hook-after-content', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: Before Title', 'hook_widgets'), 'id' => 'hook-before-title', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: After Title', 'hook_widgets'), 'id' => 'hook-after-title', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: Before Sidebar ', 'hook_widgets'), 'id' => 'hook-before-sidebar', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: After Sidebar', 'hook_widgets'), 'id' => 'hook-after-sidebar', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: Before Footer', 'hook_widgets'), 'id' => 'hook-before-footer', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
	register_sidebar( array( 'name' => __('Base: After Footer', 'hook_widgets'), 'id' => 'hook-after-footer', 'before_widget' => '<div id="%1$s" class="widget %2$s widget-%2$s"><div class="widget-inside">', 'after_widget' => '</div></div>', 'before_title' => '<h3 class="widget-title">', 'after_title' => '</h3>' ) );
}


/**
 * Output the Before Header widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_before_header() {
	if ( !is_active_sidebar( 'hook-before-header' ) )
		return;

	echo '<div id="utility-before-header" class="utility utility-before-header grid_12">';
		dynamic_sidebar( 'hook-before-header' );
	echo '</div>';
}

/**
 * Output the Header widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_header() {
	if ( !is_active_sidebar( 'hook-header' ) )
		return;

	echo '<div id="utility-header" class="utility utility-header">';
		dynamic_sidebar( 'hook-header' );
	echo '</div>';
}

/**
 * Output the After Header widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_after_header() {
	if ( !is_active_sidebar( 'hook-after-header' ) )
		return;

	echo '<div id="utility-after-header" class="utility utility-after-header grid_12">';
		dynamic_sidebar( 'hook-after-header' );
	echo '</div>';
}

/**
 * Output the Before Content widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_before_content() {
	if ( !is_active_sidebar( 'hook-before-content' ) )
		return;

	echo '<div id="utility-before-content" class="utility utility-before-content">';
		dynamic_sidebar( 'hook-before-content' );
	echo '</div>';
}

/**
 * Output the After Content widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_after_content() {
	if ( !is_active_sidebar( 'hook-after-content' ) )
		return;

	echo '<div id="utility-after-content" class="utility utility-after-content">';
		dynamic_sidebar( 'hook-after-content' );
	echo '</div>';
}

/**
 * Output the Before Title widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_before_title() {
	if ( !is_active_sidebar( 'hook-before-title' ) )
		return;

	echo '<div id="utility-before-title" class="utility utility-before-title">';
		dynamic_sidebar( 'hook-before-title' );
	echo '</div>';
}

/**
 * Output the After Title widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_after_title() {
	if ( !is_active_sidebar( 'hook-after-title' ) )
		return;

	echo '<div id="utility-after-title" class="utility utility-after-title">';
		dynamic_sidebar( 'hook-after-title' );
	echo '</div>';
}

/**
 * Output the Before Sidebar widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_before_sidebar() {
	if ( !is_active_sidebar( 'hook-before-sidebar' ) )
		return;

	echo '<div id="utility-before-sidebar" class="utility utility-before-sidebar grid_4">';
		dynamic_sidebar( 'hook-before-sidebar' );
	echo '</div>';
}

/**
 * Output the Below Sidebar widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_after_sidebar() {
	if ( !is_active_sidebar( 'hook-after-sidebar' ) )
		return;

	echo '<div id="utility-after-sidebar" class="utility utility-after-sidebar grid_4">';
		dynamic_sidebar( 'hook-after-sidebar' );
	echo '</div>';
}

/**
 * Output the Before Footer widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_before_footer() {
	if ( !is_active_sidebar( 'hook-before-footer' ) )
		return;

	echo '<div id="utility-before-footer" class="utility utility-before-footer grid_12">';
		dynamic_sidebar( 'hook-before-footer' );
	echo '</div>';
}


/**
 * Output the After Footer widget area.
 * @since 1.0
 */
function gpp_base_hook_widgets_after_footer() {
	if ( !is_active_sidebar( 'hook-after-footer' ) )
		return;

	echo '<div id="utility-after-footer" class="utility utility-after-footer grid_12">';
		dynamic_sidebar( 'hook-after-footer' );
	echo '</div>';
}


?>